[MOAB-dev] commit/MOAB: 2 new changesets

commits-noreply at bitbucket.org commits-noreply at bitbucket.org
Fri Aug 2 01:12:24 CDT 2013


2 new commits in MOAB:

https://bitbucket.org/fathomteam/moab/commits/970554240958/
Changeset:   970554240958
Branch:      None
User:        janehu
Date:        2013-08-02 08:08:18
Summary:     Fixed the MOAB build errors problem reported by Turner, Andrew. Moab now builds with option --with-cubit=cubit13.1 for both shared and static builds.

Affected #:  3 files

diff --git a/configure.ac b/configure.ac
index 24f425b..b08389a 100644
--- a/configure.ac
+++ b/configure.ac
@@ -1146,6 +1146,7 @@ AC_SUBST(CGM_CPPFLAGS)
 AC_SUBST(CGM_LDFLAGS)
 AC_SUBST(CGM_LTFLAGS)
 AC_SUBST(CGM_LIBS)
+AC_SUBST(CGM_DIR)
 
 AM_CONDITIONAL( HAVE_CGM, [test "x$CGM_MISSING" = "xno"] )
 

diff --git a/tools/Makefile.am b/tools/Makefile.am
index 121a101..0789a83 100644
--- a/tools/Makefile.am
+++ b/tools/Makefile.am
@@ -11,6 +11,10 @@ if ENABLE_imesh
  LDADD+= $(top_builddir)/itaps/imesh/libiMesh.la
 endif
 
+if HAVE_CGM
+ LDADD+=  ${CGM_DIR}/lib/libcgm.la
+endif 
+
 # For old (pre 1.10.x) versions of Automake
 docdir = @docdir@
 

diff --git a/tools/dagmc/Makefile.am b/tools/dagmc/Makefile.am
index b8cc771..29d43a5 100644
--- a/tools/dagmc/Makefile.am
+++ b/tools/dagmc/Makefile.am
@@ -31,7 +31,10 @@ CGM_LDFLAGS = @CGM_LDFLAGS@
 CGM_LTFLAGS = @CGM_LTFLAGS@
 CGM_LIBS = @CGM_LIBS@
 
-LDADD = libdagmc.la $(top_builddir)/src/libMOAB.la  $(CGM_LDFLAGS) $(CGM_LIBS)
+LDADD = libdagmc.la $(top_builddir)/src/libMOAB.la   
+if HAVE_CGM
+ LDADD += $(CGM_DIR)/lib/libcgm.la 
+endif
 
 TESTS = 
 if HDF5_FILE


https://bitbucket.org/fathomteam/moab/commits/58c9c0902996/
Changeset:   58c9c0902996
Branch:      master
User:        janehu
Date:        2013-08-02 08:11:22
Summary:     Merge branch 'master' of https://bitbucket.org/fathomteam/moab

Affected #:  7 files

diff --git a/doc/DG/moabDG.h b/doc/DG/moabDG.h
index ed23052..32d7fe1 100644
--- a/doc/DG/moabDG.h
+++ b/doc/DG/moabDG.h
@@ -29,7 +29,7 @@
   \section sequence  EntitySequence & SequenceData 
 
   \subsection figure1 Figure 1: EntitySequences For One SequenceData
-   <img src="../DG/figure1.jpg">
+  \image html figure1.jpg
 
   \ref dg-figures "List of Figures"
 
@@ -108,7 +108,7 @@ enforces the following four rules on its contained data:
 .
 
   \subsection figure2 Figure 2: SequenceManager and Related Classes
-   <img src="../DG/figure2.jpg">
+  \image html figure2.jpg
 
   \ref dg-figures "List of Figures"
 
@@ -187,7 +187,7 @@ than is required at a given time for contained objects.
 - MeshSet
 
   \subsection figure3 Figure 3: SequenceManager and Related Classes
-    <img src="../DG/figure3.jpg">
+  \image html figure3.jpg
 
   \ref dg-figures "List of Figures"
 

diff --git a/doc/MetaData/metadata.h b/doc/MetaData/metadata.h
index e02c112..8f81cff 100644
--- a/doc/MetaData/metadata.h
+++ b/doc/MetaData/metadata.h
@@ -204,6 +204,10 @@ Read the time step number whose time value is equal to or greater than the speci
 specified variable(s). Tag names for the variable(s) will be formed by appending the time step number
 to the variable name. Multiple time step values can be specified, separated from each other by commas.
 
+<H3>gather_set[=\<rank\>] </H3>
+
+Create a gather set (associated with tag GATHER_SET) on one processor with the specified rank, to duplicate entities on other processors. If the rank is not specified, it will be rank 0 by default. If an invalid rank is passed, no gather set will be created. Gather set is specially used by HOMME, MPAS, and any other unstructured grid.
+
 \ref md-contents "Top"
 
   \section meta-references References

diff --git a/doc/metadata_info.doc b/doc/metadata_info.doc
index a19c0a2..6e3eb34 100644
Binary files a/doc/metadata_info.doc and b/doc/metadata_info.doc differ

diff --git a/doc/metadata_info.pdf b/doc/metadata_info.pdf
index 710cc55..376aa51 100644
Binary files a/doc/metadata_info.pdf and b/doc/metadata_info.pdf differ

diff --git a/doc/user.dox.in b/doc/user.dox.in
index adb22ef..07f707f 100644
--- a/doc/user.dox.in
+++ b/doc/user.dox.in
@@ -359,7 +359,7 @@ EXAMPLE_PATTERNS       =
 # directories that contain image that are included in the documentation (see 
 # the \image command).
 
-IMAGE_PATH             = 
+IMAGE_PATH             =  @top_srcdir@/doc/DG/
 
 # The INPUT_FILTER tag can be used to specify a program that doxygen should 
 # invoke to filter for each input file. Doxygen will invoke the filter program 

diff --git a/src/io/mhdf/include/mhdf.h b/src/io/mhdf/include/mhdf.h
index 9a7a478..db36d63 100644
--- a/src/io/mhdf/include/mhdf.h
+++ b/src/io/mhdf/include/mhdf.h
@@ -70,7 +70,7 @@ extern "C" {
  * type of sufficient size to accomodate the entity IDs.  
  *
  * The \c tstt group contains four sub-groups, a datatype object, and a 
- * dataset object.  The three sub-groups are: \c nodes, \c elements, 
+ * dataset object.  The four sub-groups are: \c nodes, \c elements,
  * \c sets, and \c tags.  The dataset is named \c history .
  *
  * The \c elemtypes datatype is an enumeration of the elem topologies

diff --git a/test/io/read_nc.cpp b/test/io/read_nc.cpp
index caff6a4..0e9adf8 100644
--- a/test/io/read_nc.cpp
+++ b/test/io/read_nc.cpp
@@ -120,7 +120,7 @@ void test_read_eul_onevar()
 #endif
 
   const double eps = 0.0001;
-  double val[4 * 26];
+  double val[8 * 26];
 
   if (1 == procs) {
     Range global_quads;
@@ -128,13 +128,18 @@ void test_read_eul_onevar()
     CHECK_ERR(rval);
     CHECK_EQUAL((size_t)4608, global_quads.size());
 
-    EntityHandle gloabl_quad_ents[] = {global_quads[0], global_quads[4559], global_quads[48], global_quads[4607]};
-    rval = mb.tag_get_data(Ttag0, &gloabl_quad_ents[0], 4, val);
-
-    CHECK_REAL_EQUAL(252.8529, val[0], eps); // First global quad
-    CHECK_REAL_EQUAL(205.3905, val[26], eps); // 4660th global quad
-    CHECK_REAL_EQUAL(252.7116, val[52], eps); // 49th global quad
-    CHECK_REAL_EQUAL(200.6828, val[78], eps); // Last global quad
+    EntityHandle gloabl_quad_ents[] = {global_quads[0], global_quads[2255], global_quads[2304], global_quads[4559],
+                                       global_quads[48], global_quads[2303], global_quads[2352], global_quads[4607]};
+    rval = mb.tag_get_data(Ttag0, &gloabl_quad_ents[0], 8, val);
+
+    CHECK_REAL_EQUAL(252.8529, val[0 * 26], eps); // First global quad
+    CHECK_REAL_EQUAL(234.8390, val[1 * 26], eps); // 2256th global quad
+    CHECK_REAL_EQUAL(232.6458, val[2 * 26], eps); // 2305th global quad
+    CHECK_REAL_EQUAL(205.3905, val[3 * 26], eps); // 4560th global quad
+    CHECK_REAL_EQUAL(252.7116, val[4 * 26], eps); // 49th global quad
+    CHECK_REAL_EQUAL(232.6670, val[5 * 26], eps); // 2304th global quad
+    CHECK_REAL_EQUAL(234.6922, val[6 * 26], eps); // 2353th global quad
+    CHECK_REAL_EQUAL(200.6828, val[7 * 26], eps); // Last global quad
   }
   else if (2 == procs) {
     Range local_quads;
@@ -142,16 +147,20 @@ void test_read_eul_onevar()
     CHECK_ERR(rval);
     CHECK_EQUAL((size_t)2304, local_quads.size());
 
-    EntityHandle local_quad_ents[] = {local_quads[0], local_quads[2303]};
-    rval = mb.tag_get_data(Ttag0, &local_quad_ents[0], 2, val);
+    EntityHandle local_quad_ents[] = {local_quads[0], local_quads[1151], local_quads[1152], local_quads[2303]};
+    rval = mb.tag_get_data(Ttag0, &local_quad_ents[0], 4, val);
 
     if (0 == rank) {
-      CHECK_REAL_EQUAL(252.8529, val[0], eps); // First local quad, first global quad
-      CHECK_REAL_EQUAL(205.3905, val[26], eps); // Last local quad, 4660th global quad
+      CHECK_REAL_EQUAL(252.8529, val[0 * 26], eps); // First local quad, first global quad
+      CHECK_REAL_EQUAL(234.8390, val[1 * 26], eps); // Median local quad, 2256th global quad
+      CHECK_REAL_EQUAL(232.6458, val[2 * 26], eps); // Median local quad, 2305th global quad
+      CHECK_REAL_EQUAL(205.3905, val[3 * 26], eps); // Last local quad, 4560th global quad
     }
     else if (1 == rank) {
-      CHECK_REAL_EQUAL(252.7116, val[0], eps); // First local quad, 49th global quad
-      CHECK_REAL_EQUAL(200.6828, val[26], eps); // Last local quad, last global quad
+      CHECK_REAL_EQUAL(252.7116, val[0 * 26], eps); // First local quad, 49th global quad
+      CHECK_REAL_EQUAL(232.6670, val[1 * 26], eps); // Median local quad, 2304th global quad
+      CHECK_REAL_EQUAL(234.6922, val[2 * 26], eps); // Median local quad, 2353th global quad
+      CHECK_REAL_EQUAL(200.6828, val[3 * 26], eps); // Last local quad, last global quad
     }
   }
 }
@@ -303,6 +312,60 @@ void test_read_fv_onevar()
 
   rval = mb.tag_get_handle("T1", 26, MB_TYPE_DOUBLE, Ttag1);
   CHECK_ERR(rval);
+
+  // Check values of tag T0 (first level) at some strategically chosen places below
+  int rank = 0;
+  int procs = 1;
+#ifdef USE_MPI
+  ParallelComm* pcomm = ParallelComm::get_pcomm(&mb, 0);
+  rank = pcomm->proc_config().proc_rank();
+  procs = pcomm->proc_config().proc_size();
+#endif
+
+  const double eps = 0.0001;
+  double val[8 * 26];
+
+  if (1 == procs) {
+    Range global_quads;
+    rval = mb.get_entities_by_type(0, MBQUAD, global_quads);
+    CHECK_ERR(rval);
+    CHECK_EQUAL((size_t)3312, global_quads.size());
+
+    EntityHandle gloabl_quad_ents[] = {global_quads[0], global_quads[1619], global_quads[1656], global_quads[3275],
+                                       global_quads[36], global_quads[1655], global_quads[1692], global_quads[3311]};
+    rval = mb.tag_get_data(Ttag0, &gloabl_quad_ents[0], 8, val);
+
+    CHECK_REAL_EQUAL(253.6048, val[0 * 26], eps); // First global quad
+    CHECK_REAL_EQUAL(232.2170, val[1 * 26], eps); // 1620th global quad
+    CHECK_REAL_EQUAL(232.7454, val[2 * 26], eps); // 1657th global quad
+    CHECK_REAL_EQUAL(210.2581, val[3 * 26], eps); // 3276th global quad
+    CHECK_REAL_EQUAL(253.6048, val[4 * 26], eps); // 37th global quad
+    CHECK_REAL_EQUAL(232.9553, val[5 * 26], eps); // 1656th global quad
+    CHECK_REAL_EQUAL(232.1704, val[6 * 26], eps); // 1693th global quad
+    CHECK_REAL_EQUAL(210.2581, val[7 * 26], eps); // Last global quad
+  }
+  else if (2 == procs) {
+    Range local_quads;
+    rval = mb.get_entities_by_type(0, MBQUAD, local_quads);
+    CHECK_ERR(rval);
+    CHECK_EQUAL((size_t)1656, local_quads.size());
+
+    EntityHandle local_quad_ents[] = {local_quads[0], local_quads[827], local_quads[828], local_quads[1655]};
+    rval = mb.tag_get_data(Ttag0, &local_quad_ents[0], 4, val);
+
+    if (0 == rank) {
+      CHECK_REAL_EQUAL(253.6048, val[0 * 26], eps); // First local quad, first global quad
+      CHECK_REAL_EQUAL(232.2170, val[1 * 26], eps); // Median local quad, 1620th global quad
+      CHECK_REAL_EQUAL(232.7454, val[2 * 26], eps); // Median local quad, 1657th global quad
+      CHECK_REAL_EQUAL(210.2581, val[3 * 26], eps); // Last local quad, 3276th global quad
+    }
+    else if (1 == rank) {
+      CHECK_REAL_EQUAL(253.6048, val[0 * 26], eps); // First local quad, 37th global quad
+      CHECK_REAL_EQUAL(232.9553, val[1 * 26], eps); // Median local quad, 1656th global quad
+      CHECK_REAL_EQUAL(232.1704, val[2 * 26], eps); // Median local quad, 1693th global quad
+      CHECK_REAL_EQUAL(210.2581, val[3 * 26], eps); // Last local quad, last global quad
+    }
+  }
 }
 
 void test_read_fv_onetimestep()

Repository URL: https://bitbucket.org/fathomteam/moab/

--

This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.


More information about the moab-dev mailing list